==> gguf_connector-2.0.2-py2.py3-none-any.whl: gguf_connector/n2.py <==

import gradio as gr # optional (need gradio for lazy ui; pip install gradio)
from PIL import Image
from transformers import AutoTokenizer, AutoProcessor, AutoModelForImageTextToText

model_path = "callgg/ocr-bf16"
model = AutoModelForImageTextToText.from_pretrained(
    model_path,
    torch_dtype="auto",
    device_map="auto"
)
model.eval()

tokenizer = AutoTokenizer.from_pretrained(model_path)
processor = AutoProcessor.from_pretrained(model_path)

# Inference function
def ocr_inference(image: Image.Image, max_new_tokens: int = 4096):
    prompt = """Extract the text from the above document as if you were reading it naturally. Return the tables in html format. Return the equations in LaTeX representation. If there is an image in the document and image caption is not present, add a small description of the image inside the <img></img> tag; otherwise, add the image caption inside <img></img>. Watermarks should be wrapped in brackets. Ex: <watermark>OFFICIAL COPY</watermark>. Page numbers should be wrapped in brackets. Ex: <page_number>14</page_number> or <page_number>9/22</page_number>. Prefer using ☐ and ☑ for check boxes."""

    messages = [
        {"role": "system", "content": "You are a helpful assistant."},
        {"role": "user", "content": [
            {"type": "image", "image": image},
            {"type": "text", "text": prompt},
        ]},
    ]
    text = processor.apply_chat_template(messages, tokenize=False, add_generation_prompt=True)
    inputs = processor(text=[text], images=[image], padding=True, return_tensors="pt")
    inputs = inputs.to(model.device)

    output_ids = model.generate(**inputs, max_new_tokens=max_new_tokens, do_sample=False)
    generated_ids = [output_ids[len(input_ids):] for input_ids, output_ids in zip(inputs.input_ids, output_ids)]

    output_text = processor.batch_decode(generated_ids, skip_special_tokens=True, clean_up_tokenization_spaces=True)
    return output_text[0]

# Gradio interface
iface = gr.Interface(
    fn=ocr_inference,
    inputs=[
        gr.Image(type="pil", label="Upload Document"),
        gr.Slider(1024, 15000, value=4096, step=512, label="Max New Tokens")
    ],
    outputs=gr.Textbox(label="OCR Output", lines=20),
    title="Document OCR with Structured Output",
    description="Upload a scanned document image to extract text, tables (HTML), and math (LaTeX)."
)

iface.launch()

==> gguf_connector-2.2.8-py2.py3-none-any.whl: gguf_connector/n2.py <==

import gradio as gr # optional (need gradio for lazy ui; pip install gradio)
from PIL import Image
from transformers import AutoTokenizer, AutoProcessor, AutoModelForImageTextToText

model_path = "callgg/ocr-bf16"
model = AutoModelForImageTextToText.from_pretrained(
    model_path,
    torch_dtype="auto",
    device_map="auto"
)
model.eval()

tokenizer = AutoTokenizer.from_pretrained(model_path)
processor = AutoProcessor.from_pretrained(model_path)

# Inference function
def ocr_inference(image: Image.Image, max_new_tokens: int = 4096):
    prompt = """Extract the text from the above document as if you were reading it naturally. Return the tables in html format. Return the equations in LaTeX representation. If there is an image in the document and image caption is not present, add a small description of the image inside the <img></img> tag; otherwise, add the image caption inside <img></img>. Watermarks should be wrapped in brackets. Ex: <watermark>OFFICIAL COPY</watermark>. Page numbers should be wrapped in brackets. Ex: <page_number>14</page_number> or <page_number>9/22</page_number>. Prefer using ☐ and ☑ for check boxes."""

    messages = [
        {"role": "system", "content": "You are a helpful assistant."},
        {"role": "user", "content": [
            {"type": "image", "image": image},
            {"type": "text", "text": prompt},
        ]},
    ]
    text = processor.apply_chat_template(messages, tokenize=False, add_generation_prompt=True)
    inputs = processor(text=[text], images=[image], padding=True, return_tensors="pt")
    inputs = inputs.to(model.device)

    output_ids = model.generate(**inputs, max_new_tokens=max_new_tokens, do_sample=False)
    generated_ids = [output_ids[len(input_ids):] for input_ids, output_ids in zip(inputs.input_ids, output_ids)]

    output_text = processor.batch_decode(generated_ids, skip_special_tokens=True, clean_up_tokenization_spaces=True)
    return output_text[0]

# Gradio interface
iface = gr.Interface(
    fn=ocr_inference,
    inputs=[
        gr.Image(type="pil", label="Upload Document"),
        gr.Slider(1024, 15000, value=4096, step=512, label="Max New Tokens")
    ],
    # outputs=gr.Textbox(label="OCR Output", lines=20),
    outputs=gr.Code(lines=20, label="OCR Output", language="html"),
    title="Document OCR with Structured Output",
    description="Upload a scanned document image to extract text, tables (HTML), and math (LaTeX)."
)
iface.launch()
